@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## DateTime Format Relative Time - ~/lib/DateTime/Format/RelativeTime.pm
-## Version v0.1.3
+## Version v0.1.4
 ## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2024/12/30
-## Modified 2025/01/04
+## Modified 2025/01/05
 ## All rights reserved
 ## 
 ## 
@@ -27,7 +27,7 @@ BEGIN
     use Locale::Unicode::Data v1.3.0;
     use Scalar::Util ();
     use Want;
-    our $VERSION = 'v0.1.3';
+    our $VERSION = 'v0.1.4';
 };
 
 use strict;
@@ -86,6 +86,7 @@ sub new
     # RangeError: invalid value "plop" for option month
     my %valid_options = 
     (
+        localeMatcher           => ['lookup', 'best fit'],
         # numberingSystem is processed separately
         numberingSystem         => qr/[a-zA-Z][a-zA-Z0-9]+/,
         style                   => [qw( long narrow short )],
@@ -282,25 +283,34 @@ sub error
     my $self = shift( @_ );
     if( @_ )
     {
-        my $msg = join( '', map( ( ref( $_ ) eq 'CODE' ) ? $_->() : $_, @_ ) );
-        $self->{error} = $ERROR = DateTime::Format::RelativeTime::Exception->new({
-            skip_frames => 1,
-            message => $msg,
-        });
+        my $def = {};
+        if( @_ == 1 &&
+            defined( $_[0] ) &&
+            ref( $_[0] ) eq 'HASH' &&
+            exists( $_[0]->{message} ) )
+        {
+            $def = shift( @_ );
+        }
+        else
+        {
+            $def->{message} = join( '', map( ( ref( $_ ) eq 'CODE' ) ? $_->() : $_, @_ ) );
+        }
+        $def->{skip_frames} = 1 unless( exists( $def->{skip_frames} ) );
+        $self->{error} = $ERROR = DateTime::Format::RelativeTime::Exception->new( $def );
         if( $self->fatal )
         {
             die( $self->{error} );
         }
         else
         {
-            warn( $msg ) if( warnings::enabled() );
+            warn( $def->{message}  ) if( warnings::enabled() );
             if( Want::want( 'ARRAY' ) )
             {
                 rreturn( [] );
             }
             elsif( Want::want( 'OBJECT' ) )
             {
-                rreturn( DateTime::Format::Intl::NullObject->new );
+                rreturn( DateTime::Format::RelativeTime::NullObject->new );
             }
             return;
         }
@@ -1076,7 +1086,7 @@ For users requiring exact decimal representation beyond this precision, consider
 
 =head1 VERSION
 
-    v0.1.3
+    v0.1.4
 
 =head1 DESCRIPTION
 
@@ -1176,7 +1186,7 @@ Whether to use numeric values in the output. Possible values are C<always> and C
 
 =head2 format
 
-    my $fmt = new DateTime::Format::RelativeTime( 'en', { style => 'short' });
+    my $fmt = DateTime::Format::RelativeTime->new( 'en', { style => 'short' });
 
     say $fmt->format( 3, 'quarter' );
     # Expected output: "in 3 qtrs."
@@ -1238,7 +1248,7 @@ B<Note>: Most of the time, the formatting returned by C<format()> is consistent.
 
 =head2 formatToParts
 
-    my $fmt = new DateTime::Format::RelativeTime( 'en', { numeric => 'auto' });
+    my $fmt = DateTime::Format::RelativeTime->new( 'en', { numeric => 'auto' });
     my $parts = $fmt->formatToParts( 10, 'seconds' );
 
     say $parts->[0]->{value};
@@ -1250,7 +1260,7 @@ B<Note>: Most of the time, the formatting returned by C<format()> is consistent.
     say $parts->[2]->{value};
     # Expected output: " seconds"
 
-    my $fmt = new DateTime::Format::RelativeTime( 'en', { numeric => 'auto' });
+    my $fmt = DateTime::Format::RelativeTime->new( 'en', { numeric => 'auto' });
 
     # Format relative time using the day unit
     $fmt->formatToParts( -1, 'day' );
@@ -1304,10 +1314,10 @@ Plural forms are also permitted.
 
 =head2 resolvedOptions
 
-    my $fmt = new DateTime::Format::RelativeTime('en', { style => 'narrow' });
+    my $fmt = DateTime::Format::RelativeTime->new('en', { style => 'narrow' });
     my $options1 = $fmt->resolvedOptions();
     
-    my $fmt2 = new DateTime::Format::RelativeTime('es', { numeric => 'auto' });
+    my $fmt2 = DateTime::Format::RelativeTime->new('es', { numeric => 'auto' });
     my $options2 = $fmt2->resolvedOptions();
     
     say "$options1->{locale}, $options1->{style}, $options1->{numeric}";
@@ -1395,7 +1405,9 @@ Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
 
 =head1 SEE ALSO
 
-L<perl>
+L<Locale::Unicode::Data>, L<Locale::Unicode>, L<Locale::Intl>, L<DateTime::Format::Intl>, L<DateTime::Locale::FromCLDR>
+
+L<DateTime::Format::Natural>, L<DateTimeX::Format::Ago>
 
 =head1 COPYRIGHT & LICENSE
 
